@@ -26,6 +26,9 @@ def configure_env():
             json.dump(environment, f)
     except Exception as e:
         logger.exception(f'django-process environment could not be configured due to =>\n{e}')
+        logger.debug('configuring to current working directory instead')
+        with open(os.path.join(os.getcwd(), 'env_conf.json'), 'w') as f:
+            json.dump(environment, f)
 
 
 def run_jobs(date):
